package MFVec2f;
use strict;
use warnings;

use rlib "./";

use MFScalar;
use base qw(MFScalar);

use SFVec2f;
our $SField = new SFVec2f;

1;
__END__
